Das condições de cumprimento do regime semiaberto
Trata-se de título executivo de pena tendo por recuperando em epígrafe, condenado à pena privativa de liberdade no regime semiaberto.

Não foi realizada au diência admonitória estabelecendo as condições de cumprimento de pena nesta Comarca.

Vieram os autos para manifestação.

É o breve relato.

Inicialmente, deve-se consignar a observação de que vivemos, no interior desta unidade da federação, uma grande desproporcionalidade -- que chega a ofender o bom senso do cidadão comum  -- no tocante ao cumprimento da pena.

Tal se deve porque, em razão da ausência de unidade prisional destinada ao regime semiaberto ou aberto, os recuperandos neste regime cumprem a pena (no linguajar popular) de “assinar no Fórum”, mesmo quando condenados à prática de crimes hediondos ou equiparados.

Na percepção do cidadão comum, a única punição aqui é para os cofres públicos, que têm o trabalho administrativo e respectivo custo do trâmite de um processo de execução de pena durante anos. 

A sociedade, portanto, é lesada duas vezes: primeiramente, pela ofensa a bens jurídicos valiosos; segundo, pelo custo administrativo do processo de pena.

Se endossarmos a tese criminológica central subjacente à obra “Crime e Castigo”, de Dostoievski, podemos sustentar que essa prática institucionalizada fere o próprio senso de Justiça e reparação do autor do crime, que fica impossibilitado de, mediante um ato de reparação, obter o equilíbrio psicológico, ainda que inconsciente, decorrente de seus atos. Além disso, o trabalho e a ocupação é uma necessidade humana primária. Nas palavras de Arthur Schopenhauer: 

“...toda pessoa deve praticar algo na medida de suas capacidades. Notamos o efeito pernicioso da ausência de atividade regular, de qualquer tipo de trabalho, quando, nas longas viagens de diversão, sentimo-nos de tempos em tempos infelizes, visto que, sem ocupação propriamente dita, somos como que arrancados do nosso elemento natural. Esforço e luta contra as adversidades é uma necessidade para o homem, assim como cavar o é para a toupeira. A imobilidade que resultasse da satisfação total de um gozo constante lhe seria insuportável. Ultrapassar obstáculos é o prazer pleno de sua existência, sejam eles de tipo material tomo nas ações e nos exercícios, sejam de tipo espiritual, como nos estudos e nas investigações. A luta contra as adversidades e a vitória tornam o homem feliz. Se faltar-lhe oportunidade, irá criá-la como puder. De acordo com sua individualidade, caçará, jogará bilboquê, ou, conduzido por um pendor inconsciente de sua natureza, procurará querelas, urdirá intrigas, ou  maquinará fraudes e mil malefícios, apenas pôr fim ao seu insuportável estado de repouso. Difficilis in otio quies [A tranquilidade é difícil no ócio] (in Aforismos para Sabedoria de Vida, 2ª Ed, Martins Fontes, 2006 - destaquei o texto)” 

O art. 31 da LEP dispõe que "O condenado à pena privativa de liberdade está obrigado ao trabalho na medida de suas aptidões e capacidade". A essência do regime privativo da liberdade é o trabalho. O art. 39 da LEP dispõe que "Constituem deveres do condenado: V - execução do trabalho, das tarefas e das ordens recebidas".

Assim, tendo em vista o princípio da proporcionalidade e o interesse da sociedade, bem como o componente dignificante do trabalho, embora não exista nesta Comarca unidade prisional dedicada ao regime semiaberto, é perfeitamente defensável e desejável que ao reeducando seja imposta como condição da pena prestação de serviços à comunidade a órgãos públicos, nos termos do art. 149 da LEP: “Caberá ao Juiz da execução: 1 - designar a entidade ou programa comunitário ou estatal, devidamente credenciado ou convencionado, junto ao qual o condenado deverá trabalhar gratuitamente, de acordo com as suas aptidões".

Assim, o Parquet  propõe ao apenado as seguintes condições, requerendo sua intimação para início do cumprimento da pena: